#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# File name:    svg2eps_jpg.py
#
# Description:  Inkscape stores metadata in SVG files only.
#               svg2eps_jpg.py helps to bring all metadata where they should be,
#               with the help of ExifTool by Phil Harvey.
#               Another lack of Inkscape is that "Bitmap Export" makes PNG
#               files only. As we need JPG files we convert the PNG files
#               with "convert" from the ImageMagick suite.
#
# Usage:        python svg2eps_jpg.py file_name_without_extension
#
# Author:       Peter Burger
#
# Revisions:    2010-12-12 - Peter Burger
#
# Copyright:    Copyright 2010 by Peter Burger under LGPL
#
# References:   http://owl.phy.queensu.ca/~phil/exiftool/
#               http://www.imagemagick.org
#
# Notes:        For running svg2eps_jpg.py You need the corresponding .args files:
#               xmpcc2xmp.args - converts Inkscape SVG XPM-cc to XMP (used as stack file)
#               xmpcc2eps.args - converts Inkscape SVG XPM-cc to EPS (Postscript)
#               xmpcc2jpg.args - converts Inkscape SVG XPM-cc to JPG (IPTC, XMP[-dc,-iptcCore,-Photoshop])
#
#               Read the file svg2eps_jpg.txt for more explanation.
#

import sys
import subprocess
PIPE = subprocess.PIPE    # for piping the output of stdout and stderr

# main ========================================================================

pout_printing = True
perr_printing = True

print 'Convert tags from Inkscape SVG to EPS and JPG=============start'
print sys.argv[0]
try:
  fname = sys.argv[1]
except:
  print 'Usage: python svg2eps_jpg.py your_fname (without ".extension")'
  sys.exit()
fnameSVG = fname + '.svg'
fnameXML = fname + '.xml'
fnameEPS = fname + '.eps'
fnamePNG = fname + '.png'
fnameJPG = fname + '.jpg'
print 'You are converting:'
print 'SVG file         ', fnameSVG
print 'to               ', fnameXML
print 'inserting tags to', fnameEPS
print 'convert          ', fnamePNG
print 'to               ', fnameJPG
print 'inserting tags to', fnameJPG

# exiftool -file:all -xmp:all -X fnameSVG > fnameXML
exiftool_cmd_svg2xml = [
                        'exiftool',
                        '-file:all',
                        '-xmp:all',
                        '-X',
                        fnameSVG
                      ]
print 'exiftool_cmd_svg2xml:', exiftool_cmd_svg2xml

p = subprocess.Popen(exiftool_cmd_svg2xml, shell=False, stdout=PIPE, stderr=PIPE)
pout = p.stdout.read()
perr = p.stderr.read()
if pout_printing: print 'svg_pout:', pout
if perr_printing: print 'svg_perr:', perr, '\n'
if perr:
  print 'stopped due to an error'
  sys.exit()  # don't continue

# As piping is not possible in this manner, we write the piped stdout to fnameXML
# if there was no error (perr == None)

fd_xml = open(fnameXML, 'w')
fd_xml.write(pout)
fd_xml.close()
print 'output written to', fnameXML

# exiftool -tagsfromfile fname.xml -xmp:all -@ xmpcc2xmp.args fname.eps
exiftool_cmd_xml2eps = [
                        'exiftool',
                        '-tagsfromfile',
                        fnameXML,
                        '-xmp:all',
                        '-@',
                        'xmpcc2xmp.args',
                        fnameEPS
                       ]
print 'exiftool_cmd_xml2eps:', exiftool_cmd_xml2eps

p = subprocess.Popen(exiftool_cmd_xml2eps, shell=False, stdout=PIPE, stderr=PIPE)
pout = p.stdout.read()
perr = p.stderr.read()
if pout_printing: print 'eps_pout:', pout
if perr_printing: print 'eps_perr:', perr, '\n'
if perr:
  print 'stopped due to an error'
  sys.exit()  # don't continue
print 'XMP tags written to', fnameEPS

# exiftool -tagsfromfile fname.xml -xmp:all -@ xmpcc2eps.args fname.eps
exiftool_cmd_xml2eps = [
                        'exiftool',
                        '-tagsfromfile',
                        fnameXML,
                        '-xmp:all',
                        '-@',
                        'xmpcc2eps.args',
                        fnameEPS
                       ]
print 'exiftool_cmd_xml2eps:', exiftool_cmd_xml2eps

p = subprocess.Popen(exiftool_cmd_xml2eps, shell=False, stdout=PIPE, stderr=PIPE)
pout = p.stdout.read()
perr = p.stderr.read()
if pout_printing: print 'eps_pout:', pout
if perr_printing: print 'eps_perr:', perr, '\n'
if perr:
  print 'stopped due to an error'
  sys.exit()  # don't continue
print 'EPS tags written to', fnameEPS

# convert fnamePNG -quality 100 fnameJPG
convert_cmd_png2jpg = [
                        'convert',
                        fnamePNG,
                        '-quality',
                        '100',
                        fnameJPG,
                      ]
print 'convert_cmd_png2jpg:', convert_cmd_png2jpg

p = subprocess.Popen(convert_cmd_png2jpg, shell=False, stdout=PIPE, stderr=PIPE)
pout = p.stdout.read()
perr = p.stderr.read()
if pout_printing: print 'png_pout:', pout
if perr_printing: print 'png_perr:', perr, '\n'
if perr:
  print 'stopped due to an error'
  sys.exit()  # don't continue
print 'PNG file converted to', fnameJPG

# Excerpt from ImageMagick forum (2009-07-31):
# Imagemagick at this time has very minimal control of meta-data such as in EXIF profiles.
# It is basically not its job. Your best solution is the one you found, use a program more
# suited to that task. ExifTool or Jhead, etc...
#
# That's why we enter the metadata into fnameJPG with ExifTool, too.

# exiftool -tagsfromfile fname.xml -xmp:all -@ xmpcc2jpg.args fname.jpg
exiftool_cmd_xml2jpg = [
                        'exiftool',
                        '-tagsfromfile',
                        fnameXML,
                        '-xmp:all',
                        '-@',
                        'xmpcc2jpg.args',
                        fnameJPG
                       ]
print 'exiftool_cmd_xml2jpg:', exiftool_cmd_xml2jpg

p = subprocess.Popen(exiftool_cmd_xml2jpg, shell=False, stdout=PIPE, stderr=PIPE)
pout = p.stdout.read()
perr = p.stderr.read()
if pout_printing: print 'eps_pout:', pout
if perr_printing: print 'eps_perr:', perr, '\n'
if perr:
  print 'stopped due to an error'
  sys.exit()  # don't continue
print 'JPG tags written to', fnameJPG

print 'Convert tags from Inkscape SVG to EPS and JPG===============end'
print

# end =========================================================================
